@@ -18,9 +18,12 @@
 #include <QApplication>
 #include <QCommandLineParser>
 #include <QStandardPaths>
+#include <QSurfaceFormat>
 #include <QTextStream>
 #include <QWindow>
+#if WITH_QTWEBVIEW
 #include <QtWebView>
+#endif
 
 #include <QProcessEnvironment>
 
@@ -96,7 +99,13 @@ int main(int argc, char **argv)
 {
     // needs to be set before we create the QGuiApplication
     QCoreApplication::setAttribute(Qt::AA_DisableSessionManager, true);
+#if WITH_QTWEBVIEW
     QtWebView::initialize();
+#endif
+
+    auto format = QSurfaceFormat::defaultFormat();
+    format.setOption(QSurfaceFormat::ResetNotification);
+    QSurfaceFormat::setDefaultFormat(format);
 
     QApplication app(argc, argv);
     app.setWindowIcon(QIcon::fromTheme(QStringLiteral("plasmadiscover")));
