@@ -53,16 +53,22 @@ public:
     int originIndex(const QString &sourceId) const;
     QStandardItem *sourceByUrl(const QString &url) const;
     QStandardItem *sourceById(const QString &sourceId) const;
+    DiscoverAction *inlineAction() const override
+    {
+        return m_saveAction;
+    }
 
     void cancel() override;
     void proceed() override;
 
+    void save();
     void addRemote(FlatpakRemote *remote, FlatpakInstallation *installation);
 
 private:
     FlatpakInstallation *m_preferredInstallation;
     QStandardItemModel *m_sources;
     DiscoverAction *const m_flathubAction;
+    DiscoverAction *const m_saveAction;
     QStandardItem *m_noSourcesItem;
     QStack<std::function<void()>> m_proceedFunctions;
 };
