@@ -13,6 +13,8 @@
 #include <QSet>
 
 #include <KConfigGroup>
+#include <KFormat>
+#include <KIO/FileSystemFreeSpaceJob>
 #include <KLocalizedString>
 #include <KSharedConfig>
 
@@ -113,9 +115,9 @@ public:
         QSet<QString> donePkgs;
         for (auto res : qAsConst(m_resources)) {
             PackageKitResource *app = qobject_cast<PackageKitResource *>(res);
-            QString pkgid = m_backend->upgradeablePackageId(app);
-            if (!donePkgs.contains(pkgid)) {
-                donePkgs.insert(pkgid);
+            QString pkgname = app->packageName();
+            if (!donePkgs.contains(pkgname)) {
+                donePkgs.insert(pkgname);
                 ret += app;
             }
         }
@@ -217,7 +219,8 @@ public:
 
     void setCandidates(const QSet<AbstractResource *> &candidates)
     {
-        for (auto res : (m_resources - candidates)) {
+        const auto toDisconnect = (m_resources - candidates);
+        for (auto res : toDisconnect) {
             disconnect(res, &AbstractResource::sizeChanged, this, &SystemUpgrade::refreshResource);
         }
 
@@ -268,6 +271,15 @@ void PackageKitUpdater::prepare()
     } else {
         m_toUpgrade = candidates;
     }
+
+    auto j = KIO::fileSystemFreeSpace(QUrl::fromLocalFile("/usr"));
+    connect(j, &KIO::FileSystemFreeSpaceJob::result, this, [this](KIO::Job * /*job*/, KIO::filesize_t /*size*/, KIO::filesize_t available) {
+        if (available < updateSize()) {
+            setErrorMessage(i18nc("@info:status %1 is a formatted disk space string e.g. '240 MiB'",
+                                  "Not enough space to perform the update; only %1 of space are available.",
+                                  KFormat().formatByteSize(available)));
+        }
+    });
     m_allUpgradeable = m_toUpgrade;
 }
 
@@ -336,13 +348,13 @@ QSet<QString> PackageKitUpdater::involvedPackages(const QSet<AbstractResource *>
         }
 
         PackageKitResource *app = qobject_cast<PackageKitResource *>(res);
-        const QString pkgid = m_backend->upgradeablePackageId(app);
-        if (pkgid.isEmpty()) {
+        const QSet<QString> ids = m_backend->upgradeablePackageId(app);
+        if (ids.isEmpty()) {
             qWarning() << "no upgradeablePackageId for" << app;
             continue;
         }
 
-        packageIds.insert(pkgid);
+        packageIds.unite(ids);
     }
     return packageIds;
 }
@@ -438,7 +450,7 @@ void PackageKitUpdater::finished(PackageKit::Transaction::Exit exit, uint /*time
 
         if (!toremove.isEmpty()) {
             QStringList criticals;
-            for (const auto &pkgid : toremove) {
+            for (const auto &pkgid : std::as_const(toremove)) {
                 auto res = kFilter<QVector<AbstractResource *>>(m_backend->resourcesByPackageName(pkgid), [](AbstractResource *res) {
                     return static_cast<PackageKitResource *>(res)->isCritical();
                 });
@@ -476,6 +488,7 @@ void PackageKitUpdater::finished(PackageKit::Transaction::Exit exit, uint /*time
 
     if (useOfflineUpdates() && exit == PackageKit::Transaction::ExitSuccess) {
         PackageKit::Daemon::global()->offline()->trigger(PackageKit::Offline::ActionReboot);
+        enableReadyToReboot();
     }
 }
 
@@ -557,7 +570,7 @@ void PackageKitUpdater::errorFound(PackageKit::Transaction::Error err, const QSt
         || err == PackageKit::Transaction::ErrorNotAuthorized) {
         return;
     }
-    QString finalMessage = xi18nc("@info", "%1:<nl/><nl/>%2", PackageKitMessages::errorMessage(err), error);
+    QString finalMessage = xi18nc("@info", "%1:<nl/><nl/>%2", PackageKitMessages::errorMessage(err, QString()), error);
     Q_EMIT passiveMessage(finalMessage);
     qWarning() << "Error happened" << err << error;
 }
@@ -739,9 +752,9 @@ double PackageKitUpdater::updateSize() const
         }
 
         PackageKitResource *app = qobject_cast<PackageKitResource *>(res);
-        QString pkgid = m_backend->upgradeablePackageId(app);
-        if (!donePkgs.contains(pkgid)) {
-            donePkgs.insert(pkgid);
+        QString pkgname = app->packageName();
+        if (!donePkgs.contains(pkgname)) {
+            donePkgs.insert(pkgname);
             ret += app->size();
         }
     }
